@@ -30,16 +30,11 @@
 #include <gdk_imlib.h>
 #include <glade/glade.h>
 #include <libgnomeui/gnome-window-icon.h>
-#include "applet-widget.h"
-
-/* headers for select & child stuff */
-#include <sys/time.h>
-#include <sys/types.h>
-#include <sys/wait.h>
-#include <unistd.h>
+#include <applet-widget.h>
 
 #include <signal.h>
 
+#include "gpilot-applet-progress.h"
 #include "gpilotd/gnome-pilot-client.h"
 
 enum {
@@ -64,11 +59,12 @@ typedef struct {
 
 static pilot_properties properties = { NULL };
 
-typedef enum { INITIALISING, CONNECTING_TO_DAEMON, SYNCING, WAITING, NUM_STATES } state;
+typedef enum { INITIALISING, PAUSED, CONNECTING_TO_DAEMON, SYNCING, WAITING, NUM_STATES } state;
 
 char *pixmaps[] = 
 {
     "sync_broken.png",
+    "sync_paused.png",
     "sync_icon.png",
     "syncing_icon.png",
     "sync_icon.png",
@@ -80,6 +76,7 @@ static GtkWidget *pixmap;
 static GtkWidget *dialogWindow; 
 static GtkWidget *operationDialogWindow;
 static GtkWidget *pb = NULL;
+static GPilotAppletProgress *c_progress;
 
 guint timeout_handler_id;
 gboolean double_clicked;
@@ -98,6 +95,7 @@ static GnomePilotClient *gpc = NULL;
 static void show_error_dialog (gchar*,...);
 static void show_warning_dialog (gchar*,...);
 static void show_message_dialog (gchar*,...);
+static void pause_cb (AppletWidget *widget, gpointer data);
 static void resume_cb (AppletWidget *widget, gpointer data);
 static void cancel_cb (GtkButton* button,gpointer whatever);
 
@@ -157,6 +155,9 @@ gpilotd_connect_cb (GnomePilotClient* client,
 	gtk_progress_configure (GTK_PROGRESS (overall_progress_bar),0 ,0, 1);
 	gtk_progress_configure (GTK_PROGRESS (conduit_progress_bar),0 ,0, 100.0);
 
+	gpilot_applet_progress_set_progress (c_progress, GTK_PROGRESS (conduit_progress_bar));
+	gpilot_applet_progress_start (c_progress);
+
 	colormap = gdk_window_get_colormap (message_area->window);
 	gdk_color_parse ("red",&errorColor);
 	gdk_colormap_alloc_color (colormap,&errorColor,FALSE,TRUE);
@@ -172,6 +173,7 @@ gpilotd_disconnect_cb (GnomePilotClient* client,
 	curstate = WAITING;
 	pilot_draw (pixmap);
 	if (properties.popups && progressDialog!=NULL) {
+		gpilot_applet_progress_stop (c_progress);
 		gtk_widget_hide (progressDialog);
 	}
 }
@@ -206,7 +208,8 @@ gpilotd_conduit_start (GnomePilotClient* client,
 	if (properties.popups && progressDialog!=NULL) {
 		gchar *txt=g_strdup_printf (_("%s Synchronizing : %s"),id, conduit);
 		gtk_label_set_text (GTK_LABEL (sync_label),txt);
-		gtk_progress_configure (GTK_PROGRESS (conduit_progress_bar),0,0,100);
+		gtk_progress_configure (GTK_PROGRESS (conduit_progress_bar), 0, 0, 100);
+		gpilot_applet_progress_start (c_progress);
 		g_free (txt);
 		txt=g_strdup_printf (_("%s: Started\n"),conduit);
 		gtk_text_insert (GTK_TEXT (message_area),NULL,NULL,NULL,txt,-1);
@@ -223,6 +226,7 @@ gpilotd_conduit_end (GnomePilotClient* client,
 	if (properties.popups && progressDialog!=NULL) {
 		gchar *txt=g_strdup_printf (_("%s Finished : %s"),id, conduit);
 		gtk_progress_configure (GTK_PROGRESS (conduit_progress_bar),100,0,100);
+		gpilot_applet_progress_start (c_progress);
 		gtk_label_set_text (GTK_LABEL (sync_label),txt);
 		g_free (txt);
 		txt=g_strdup_printf (_("%s: Ended\n"),conduit);
@@ -248,8 +252,9 @@ gpilotd_conduit_progress (GnomePilotClient* client,
         total,abs (cur_f/(tot_f/100)));
 */
 	if (properties.popups && progressDialog!=NULL) {
-		gtk_progress_configure (GTK_PROGRESS (conduit_progress_bar),cur_f,1,tot_f); 
+		gtk_progress_configure (GTK_PROGRESS (conduit_progress_bar), cur_f, 1, tot_f); 
 		gtk_progress_set_format_string (GTK_PROGRESS (conduit_progress_bar), _("%v of %u records"));
+		gpilot_applet_progress_stop (c_progress);
 	}
 }
 
@@ -300,9 +305,9 @@ gpilotd_daemon_message (GnomePilotClient* client,
 
 static void 
 gpilotd_daemon_error (GnomePilotClient* client, 
-			 const gchar *id, 
-			 const gchar *message,
-			 gpointer unused) 
+		      const gchar *id, 
+		      const gchar *message,
+		      gpointer unused) 
 {
 	if (properties.popups && progressDialog != NULL) {
 		gchar *txt=g_strdup_printf ("Error: %s\n", message);
@@ -311,6 +316,59 @@ gpilotd_daemon_error (GnomePilotClient* client,
 	}
 }
 
+static void
+handle_client_error (void)
+{
+	if (curstate == SYNCING) {
+		show_warning_dialog (_("Pilot is currently synchronizing.\nPlease wait for it to finish."));
+	} else {
+		curstate=INITIALISING;
+		applet_widget_set_tooltip (APPLET_WIDGET (applet),_("Not connected. Please restart daemon."));	
+		pilot_draw (pixmap);
+		show_error_dialog (_("Not connected to gpilotd.\nPlease restart daemon."));
+	}
+}
+
+static void
+gpilotd_daemon_pause (GnomePilotClient *client,
+		      gboolean on_off,
+		      gpointer unused)
+{
+	if (!GTK_WIDGET_REALIZED (pixmap)) {
+		g_warning ("! realized");
+		return;
+	}
+
+	if (on_off) {
+		if (curstate == WAITING) {
+			curstate = PAUSED;
+			applet_widget_set_tooltip (APPLET_WIDGET (applet),_("Daemon paused..."));
+			applet_widget_register_stock_callback (APPLET_WIDGET (applet),
+							       "stop",
+							       GNOME_STOCK_MENU_REFRESH,
+							       _("Resume daemon"),
+							       resume_cb,
+							       NULL);
+		} else {
+			handle_client_error ();
+		}
+	} else {
+		curstate = WAITING;
+		applet_widget_set_tooltip (APPLET_WIDGET (applet),_("Ready to synchronize"));
+		applet_widget_register_stock_callback (APPLET_WIDGET (applet),
+						      "stop",
+						      GNOME_STOCK_PIXMAP_STOP,
+						      _("Pause daemon"),
+						      pause_cb,
+						      NULL);
+	}
+  
+	pilot_draw (pixmap);
+
+	g_message ("paused");
+	
+}
+
 static void 
 gpilotd_conduit_error (GnomePilotClient* client, 
 		       const gchar *id, 
@@ -455,6 +513,7 @@ timeout (gpointer data)
 		}
 		break;
 	case SYNCING: 
+	case PAUSED:
 		break;
 	}
 
@@ -508,19 +567,6 @@ show_message_dialog (char *mesg,...)
 	va_end (ap);
 }
 
-static void
-handle_client_error (void)
-{
-	if (curstate == SYNCING) {
-		show_warning_dialog (_("Pilot is currently synchronizing.\nPlease wait for it to finish."));
-	} else {
-		curstate=INITIALISING;
-		applet_widget_set_tooltip (APPLET_WIDGET (applet),_("Not connected. Please restart daemon."));	
-		pilot_draw (pixmap);
-		show_error_dialog (_("Not connected to gpilotd.\nPlease restart daemon."));
-	}
-}
-
 static void
 load_properties (char *cfgpath)
 {
@@ -982,37 +1028,20 @@ restart_cb (AppletWidget *widget, gpointer data)
 }
 
 static void
-pause_cb (AppletWidget *widget, gpointer data)
+resume_cb (AppletWidget *widget, gpointer data)
 {
-	if (curstate==WAITING &&	gnome_pilot_client_pause_daemon (gpc)==GPILOTD_OK) {
-		applet_widget_set_tooltip (APPLET_WIDGET (applet),_("Daemon paused"));
-		applet_widget_register_stock_callback (APPLET_WIDGET (applet),
-						      "stop",
-						      GNOME_STOCK_MENU_REFRESH,
-						      _("Resume daemon"),
-						      resume_cb,
-						      NULL);
-	} else {
-		handle_client_error ();
-	}
+ 	if (! (curstate==PAUSED && gnome_pilot_client_unpause_daemon (gpc)==GPILOTD_OK)) {
+  		handle_client_error ();
+  	}
+	return;
 }
 
 static void
-resume_cb (AppletWidget *widget, gpointer data)
+pause_cb (AppletWidget *widget, gpointer data)
 {
-	if (curstate==WAITING &&	gnome_pilot_client_unpause_daemon (gpc)==GPILOTD_OK) {
-
-		applet_widget_set_tooltip (APPLET_WIDGET (applet),_("Ready to synchronize"));
-		applet_widget_register_stock_callback (APPLET_WIDGET (applet),
-						      "stop",
-						      GNOME_STOCK_PIXMAP_STOP,
-						      _("Pause daemon"),
-						      pause_cb,
-						      NULL);
-	} else {
+	if (! (curstate==WAITING && gnome_pilot_client_pause_daemon (gpc)==GPILOTD_OK)) {		
 		handle_client_error ();
 	}
-        return;
 }
 
 static GtkWidget *
@@ -1033,6 +1062,8 @@ create_pilot_widget (GtkWidget *window)
 							  "the GnomePilot Daemon"));
 
 
+	c_progress = GPILOT_APPLET_PROGRESS (gpilot_applet_progress_new ());
+
 	curstate = INITIALISING;
 
 	for (i = 0; i < sizeof (pixmaps)/sizeof (pixmaps[0]); i++)
@@ -1256,6 +1287,9 @@ main (int argc, char *argv[])
 	gtk_signal_connect_object (GTK_OBJECT (gpc),
 				  GNOME_PILOT_CLIENT_SIGNAL_ERROR_DAEMON (gpilotd_daemon_error),
 				   NULL);
+	gtk_signal_connect_object (GTK_OBJECT (gpc),
+				  GNOME_PILOT_CLIENT_SIGNAL_DAEMON_PAUSE (gpilotd_daemon_pause),
+				   NULL);
 
 	applet_factory_new ("gpilot-applet_factory", NULL, applet_start_new_applet);
 
