@@ -23,35 +23,39 @@
  *
  */
 
+#ifdef HAVE_CONFIG_H
 #include "config.h"
+#endif
 
 #ifdef USE_XOPEN_SOURCE
 #define _XOPEN_SOURCE 
 #endif
 
-#include <sys/types.h>
+#include <glib.h>
+
 #include <pwd.h>
 #include <errno.h>
-#include <sys/time.h>
-#include <glib.h>
-#include "manager.h"
-#include <libgnome/libgnome.h>
 #include <string.h>
-#include "gnome-pilot-structures.h"
-#include <unistd.h>
 #include <signal.h>
+#include <sys/types.h>
+#include <sys/stat.h>
+#include <sys/wait.h>
+#include <sys/time.h>
+#include <unistd.h>
+#include <stdio.h>
+
+#include <libgnome/libgnome.h>
+
 #include <pi-source.h>
 #include <pi-dlp.h>
 #include <pi-version.h>
-#include <sys/wait.h>
-#include <sys/stat.h>
-#include <pwd.h>
 
+#include "manager.h"
+#include "gnome-pilot-structures.h"
 #include "orbit_daemon_glue.h"
 #include "gpilot-gui.h"
-#include <errno.h>
-
 #include "gnome-pilot-conduit-backup.h"
+
 #include <libgpilotdCM/gnome-pilot-conduit-management.h>
 
 /* Set to true when the config should be reloaded */
@@ -159,6 +163,7 @@ pilot_connect (GPilotDevice *device,int *error)
 		if (error) *error = 2;
 		return 0;
 	}
+
 	if (error) *error = 0;
 	return sd;
 }
@@ -217,38 +222,6 @@ match_pilot_and_majick (const GPilotPilot *pilot,
 
 /**************************/
 
-
-/* 
- * Start restoring a pilot profile, using the given (open hopefully)
- * filedescriptor, given a device (in case we need it again) and the
- * pilot info structure
- */
-
-static gboolean
-gpilot_start_restore (int pfd, 
-		      GPilotDevice *device,
-		      GPilotPilot *pilot)
-{
-	GnomePilotConduitManagement *gpcm;
-	GnomePilotConduit *conduit;
-	int err;
-	gboolean result = TRUE;
-
-	gpcm = gnome_pilot_conduit_management_new ("gpbackup1", GNOME_PILOT_CONDUIT_MGMT_ID);
-	err = gnome_pilot_conduit_management_instantiate_conduit (gpcm,
-								  pilot,
-								  &conduit);
-	if (err == GNOME_PILOT_CONDUIT_MGMT_OK && GNOME_IS_PILOT_CONDUIT_BACKUP (conduit)) {
-		gnome_pilot_conduit_backup_restore (GNOME_PILOT_CONDUIT_BACKUP (conduit),
-						    pfd, 
-						    NULL);
-	} else {
-		result = FALSE;
-	}
-							    
-	return result;
-}
-
 /*
  * We get a pfd, a device and the context (called if a pilot
  * with id == 0 synchronizes)
@@ -258,7 +231,8 @@ gpilot_start_restore (int pfd,
  */
 
 static gboolean
-gpilot_attempt_restore (int pfd, 
+gpilot_attempt_restore (struct PilotUser pu,
+			int pfd, 
 			GPilotDevice *device, 
 			GPilotContext *context)
 {
@@ -289,7 +263,9 @@ gpilot_attempt_restore (int pfd,
 		GPilotPilot *a_pilot;
 		a_pilot = gpilot_gui_restore (context, pilot);
 		if (a_pilot) {
-			result = gpilot_start_restore (pfd, device, a_pilot);
+			orbed_notify_connect (pilot->name,pu);				
+			result = gpilot_start_unknown_restore (pfd, device, a_pilot);
+			orbed_notify_disconnect (pilot->name);
 		}
 	} else {
 		/* MUST GO */
@@ -300,7 +276,7 @@ gpilot_attempt_restore (int pfd,
 					   cardinfo.creation,
 					   sysinfo.romVersion);
 	}
-	pilot_disconnect (pfd);		
+
 	return TRUE;
 }
 
@@ -321,13 +297,12 @@ gpilot_syncing_unknown_pilot (struct PilotUser pu,
 	   has password set
 	   bug # 8217 */
 	if (pu.userID == 0) {
-		if (gpilot_attempt_restore (pfd, device, context) == FALSE) {
+		if (gpilot_attempt_restore (pu, pfd, device, context) == FALSE) {
 			gpilot_gui_warning_dialog (_("Use gnomecc to configure pilot"));
 		}
 	} else {
 		/* FIXME: here we should offer to create a profile for the pilot,
 		   bug # 8218 */
-		pilot_disconnect (pfd);
 		gpilot_gui_warning_dialog (_("Unknown pilot - no pilots matches ID %ld\n"
 					     "Use gnomecc to set pilot's ID"),pu.userID);
 	}
@@ -352,7 +327,7 @@ do_cradle_events (int pfd,
 	   in orbed_notify_completion */
 	events = gpc_queue_load_requests_for_cradle (device->name);
 
-	g_message (_("Cradle %s has %d events"),device->name,g_list_length (events));
+	g_message (_("Cradle %s has %d events"), device->name, g_list_length (events));
 
 	/* if no events, return FALSE */
 	if (g_list_length (events)==0) ret = FALSE;
@@ -365,7 +340,7 @@ do_cradle_events (int pfd,
 		switch (req->type) {
 		case GREQ_SET_USERINFO:
 			g_message (_("Setting userinfo..."));
-			g_snprintf (pu->username,127,"%s",req->parameters.set_userinfo.user_id);
+			g_snprintf (pu->username,127,"%s", req->parameters.set_userinfo.user_id);
 			pu->userID = req->parameters.set_userinfo.pilot_id;
 			dlp_WriteUserInfo (pfd,pu);
 			if (req->parameters.set_userinfo.continue_sync) {
@@ -565,10 +540,9 @@ gpilot_syncing_known_pilot (GPilotPilot *pilot,
 {
 	struct stat buf; 
 	int ret;
-	
-	orbed_notify_connect (pilot->name,pu);
-	
-	ret=stat (pilot->sync_options.basedir, &buf); 
+		
+	ret = stat (pilot->sync_options.basedir, &buf); 
+
 	if (ret < 0 || !( S_ISDIR (buf.st_mode) && (buf.st_mode & (S_IRUSR | S_IWUSR |S_IXUSR))) ) {
 		
 		g_message ("Invalid basedir: %s", pilot->sync_options.basedir);
@@ -576,7 +550,7 @@ gpilot_syncing_known_pilot (GPilotPilot *pilot,
 					     "Please fix it or use gnomecc to choose another directory."),
 					   pilot->sync_options.basedir);	
 	} else {
-		
+		gboolean pwd_ok = TRUE;
 		/* If pilot has password, check against the encrypted version
 		   on the pilot */
 		if (pilot->passwd) {
@@ -584,18 +558,17 @@ gpilot_syncing_known_pilot (GPilotPilot *pilot,
 			pwd = (char*)g_malloc (pu.passwordLength);
 			strncpy (pwd,pu.password,pu.passwordLength);
 			if (g_strcasecmp (pilot->passwd,(char*)crypt (pwd,pilot->passwd))) {
-				pilot_disconnect (pfd);
-				orbed_notify_disconnect (pilot->name);
+				pwd_ok = FALSE;
 				gpilot_gui_warning_dialog (_("Unknown pilot - no pilots matches ID %ld\n"
 							     "Use gnomecc to set pilot's ID"),pu.userID);
 			}
 			g_free (pwd);
 		} 
 		
-		do_sync (pfd,context,&pu,pilot,device);
+		if (pwd_ok) {
+			do_sync (pfd,context,&pu,pilot,device);
+		}
 	}
-	pilot_disconnect (pfd);
-	orbed_notify_disconnect (pilot->name);
 }
 
 /*
@@ -637,24 +610,27 @@ sync_device (GPilotDevice *device, GPilotContext *context)
 		if (dlp_ReadUserInfo (pfd,&pu) < 0) {
 			/* no ? drop connection then */
 			g_warning (_("An error occured while getting the pilot's user data"));
-			pilot_disconnect (pfd);
 		} else {
+	
 			/* If there are cradle specific events, handle them and stop */
 			if (do_cradle_events (pfd,context,&pu,device)) {
 				g_message (_("Completed events for cradle %s (%s)"),device->name,device->port);
-				pilot_disconnect (pfd);
 			} else {
 				/* No cradle events, validate pilot */
 				pilot = gpilot_find_pilot_by_id (pu.userID,context->pilots);
+
 				if (pilot == NULL) {
 					/* Pilot is not known */
 					gpilot_syncing_unknown_pilot (pu, pfd, device, context);
 				} else {
 					/* Pilot is known, make connect notifications */
+					orbed_notify_connect (pilot->name,pu);				
 					gpilot_syncing_known_pilot (pilot, pu, pfd, device, context);
-				}
+					orbed_notify_disconnect (pilot->name);
+				}				
 			}
 		}
+		pilot_disconnect (pfd);
 		close (pfd);
 	} else {
 		if (connect_error==1) return FALSE; /* remove this device */
@@ -693,7 +669,7 @@ device_in (GIOChannel *io_channel,
 #ifdef WITH_IRDA
 	if (device->type == PILOT_DEVICE_IRDA) {
 		g_message ("Restarting irda funk...");
-		gpilot_device_free (device);
+		gpilot_device_deinit (device);
 		gpilot_device_init (device);
 		monitor_channel (device, context);
 		result = FALSE;
@@ -994,6 +970,7 @@ remove_pid_file () {
 					   strlen ("/.gpilotd.pid") + 1);
 		strcpy (pid_file,home_directory);
 		strcat (pid_file,"/.gpilotd.pid");
+
 		if (access (pid_file,R_OK|W_OK)==0) {
 			unlink (pid_file);
 		} 
